netapp_ontap.models.zapp_s3_bucket_application_components_access_policies API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_s3_bucket_application_components_access_policies`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappS3BucketApplicationComponentsAccessPoliciesSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappS3BucketApplicationComponentsAccessPolicies object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `actions: List[str] GET POST PATCH`

    The actions field of the zapp_s3_bucket_application_components_access_policies.

  `conditions: List[ZappS3BucketApplicationComponentsAccessPoliciesConditions] GET POST`

    conditions.

  `effect: str GET POST`

    Allow or Deny Access.

    Valid choices:

    - allow
    - deny
  `principals: List[str] GET POST PATCH`

    The principals field of the zapp_s3_bucket_application_components_access_policies.

  `resources: List[str] GET POST PATCH`

    The resources field of the zapp_s3_bucket_application_components_access_policies.

  `sid: str GET POST`

    Statement Identifier Usage: <(size 1..256)>